pub struct Localized { /* private fields */ }Expand description
A type which formats a localized message with any number of named arguments.
Implementations
Sourceimpl Localized
impl Localized
Sourcepub fn new(key: &str) -> Self
pub fn new(key: &str) -> Self
Creates a new Localized type with a given key.
The given key is used to retrieve a translation from a fluent bundle resource.
Example
Application::new(|cx|{
Label::new(cx, Localized::new("key"));
})
.run();Sourcepub fn map(self, mapping: impl Fn(&str) -> String + 'static) -> Self
pub fn map(self, mapping: impl Fn(&str) -> String + 'static) -> Self
Sets a mapping function to apply to the translated text.
Sourcepub fn attribute(self, attr_name: &str) -> Self
pub fn attribute(self, attr_name: &str) -> Self
Selects a message attribute to translate instead of the message value.
Messages can contain multiple attributes that define alternative translations. This method allows you to select a specific attribute by name.
Example
Application::new(|cx|{
// Resolves the "title" attribute of the "dialog" message
Label::new(cx, Localized::new("dialog").attribute("title"));
})
.run();Sourcepub fn arg<R, T>(self, key: &str, res: R) -> Self
pub fn arg<R, T>(self, key: &str, res: R) -> Self
Takes a key name and a resource for the argument value.
This accepts both plain values and reactive resources.
Example
Application::new(|cx|{
AppData {
value: 5,
}.build(cx);
Label::new(cx, Localized::new("key").arg("value", AppData::value));
})
.run();Trait Implementations
Sourceimpl Res<String> for Localized
impl Res<String> for Localized
Sourcefn get_value(&self, cx: &impl DataContext) -> String
fn get_value(&self, cx: &impl DataContext) -> String
Returns the value of a resource by value.
fn set_or_bind<F>(self, cx: &mut Context, closure: F)
Sourceimpl ToStringLocalized for Localized
impl ToStringLocalized for Localized
Sourcefn to_string_local(&self, cx: &impl DataContext) -> String
fn to_string_local(&self, cx: &impl DataContext) -> String
Method for converting the current type to a
String via a translation using fluent.Auto Trait Implementations
impl Freeze for Localized
impl !RefUnwindSafe for Localized
impl !Send for Localized
impl !Sync for Localized
impl Unpin for Localized
impl UnsafeUnpin for Localized
impl !UnwindSafe for Localized